@@ -8,19 +8,15 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_apigateway._jsii
-import aws_cdk.aws_events._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import cloudcomponents.cdk_secret_key._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-stripe-webhook",
-    "1.49.0",
+    "2.0.0",
     __name__[0:-6],
-    "cdk-stripe-webhook@1.49.0.jsii.tgz",
+    "cdk-stripe-webhook@2.0.0.jsii.tgz",
 )
 
 __all__ = [
